@@ -40,7 +40,7 @@ if _COMET_AVAILABLE:
 
     try:
         from comet_ml.api import API
-    except ImportError:  # pragma: no-cover
+    except ModuleNotFoundError:  # pragma: no-cover
         # For more information, see: https://www.comet.ml/docs/python-sdk/releases/#release-300
         from comet_ml.papi import API  # pragma: no-cover
 else:
@@ -120,7 +120,7 @@ class CometLogger(LightningLoggerBase):
             :class:`CometExperiment` can be passed as keyword arguments in this logger.
 
     Raises:
-        ImportError:
+        ModuleNotFoundError:
             If required Comet package is not installed on the device.
         MisconfigurationException:
             If neither ``api_key`` nor ``save_dir`` are passed as arguments.
@@ -141,9 +141,8 @@ class CometLogger(LightningLoggerBase):
         **kwargs,
     ):
         if comet_ml is None:
-            raise ImportError(
-                "You want to use `comet_ml` logger which is not installed yet,"
-                " install it with `pip install comet-ml`."
+            raise ModuleNotFoundError(
+                "You want to use `comet_ml` logger which is not installed yet, install it with `pip install comet-ml`."
             )
         super().__init__()
         self._experiment = None
@@ -269,10 +268,20 @@ class CometLogger(LightningLoggerBase):
 
     @property
     def save_dir(self) -> Optional[str]:
+        """Gets the save directory.
+
+        Returns:
+            The path to the save directory.
+        """
         return self._save_dir
 
     @property
     def name(self) -> str:
+        """Gets the project name.
+
+        Returns:
+            The project name if it is specified, else "comet-default".
+        """
         # Don't create an experiment if we don't have one
         if self._experiment is not None and self._experiment.project_name is not None:
             return self._experiment.project_name
@@ -284,6 +293,18 @@ class CometLogger(LightningLoggerBase):
 
     @property
     def version(self) -> str:
+        """Gets the version.
+
+        Returns:
+            The first one of the following that is set in the following order
+
+            1. experiment id.
+            2. experiment key.
+            3. "COMET_EXPERIMENT_KEY" environment variable.
+            4. future experiment key.
+
+            If none are present generates a new guid.
+        """
         # Don't create an experiment if we don't have one
         if self._experiment is not None:
             return self._experiment.id
