@@ -22,6 +22,7 @@ from torch.nn.parallel import DistributedDataParallel
 import pytorch_lightning as pl
 from pytorch_lightning.overrides.base import unwrap_lightning_module
 from pytorch_lightning.plugins.environments.cluster_environment import ClusterEnvironment
+from pytorch_lightning.plugins.io.checkpoint_plugin import CheckpointIO
 from pytorch_lightning.plugins.training_type.training_type_plugin import TrainingTypePlugin
 from pytorch_lightning.utilities import _XLA_AVAILABLE
 from pytorch_lightning.utilities.distributed import all_gather_ddp_if_available, ReduceOp
@@ -34,15 +35,16 @@ class ParallelPlugin(TrainingTypePlugin, ABC):
         self,
         parallel_devices: Optional[List[torch.device]] = None,
         cluster_environment: Optional[ClusterEnvironment] = None,
+        checkpoint_io: Optional[CheckpointIO] = None,
     ):
-        super().__init__()
+        super().__init__(checkpoint_io)
         self.parallel_devices = parallel_devices
         self.cluster_environment = cluster_environment
 
     @property
     @abstractmethod
     def root_device(self) -> torch.device:
-        raise NotImplementedError
+        """Return the root device."""
 
     @property
     def on_gpu(self) -> bool:
@@ -82,12 +84,10 @@ class ParallelPlugin(TrainingTypePlugin, ABC):
         return distributed_sampler_kwargs
 
     def reconciliate_processes(self, trace: str):
-        """
-        Function to re-conciliate processes on failure
-        """
+        """Function to re-conciliate processes on failure."""
 
     def all_gather(self, tensor: torch.Tensor, group: Optional[Any] = None, sync_grads: bool = False) -> torch.Tensor:
-        """Perform a all_gather on all processes"""
+        """Perform a all_gather on all processes."""
         return all_gather_ddp_if_available(tensor, group=group, sync_grads=sync_grads)
 
     def reduce_boolean_decision(self, decision: bool) -> bool:
@@ -105,8 +105,7 @@ class ParallelPlugin(TrainingTypePlugin, ABC):
 
     @staticmethod
     def configure_sync_batchnorm(model: "pl.LightningModule") -> "pl.LightningModule":
-        """
-        Add global batchnorm for a model spread across multiple GPUs and nodes.
+        """Add global batchnorm for a model spread across multiple GPUs and nodes.
 
         Override to synchronize batchnorm between specific process groups instead
         of the whole world or use a different sync_bn like `apex`'s version.
@@ -121,8 +120,8 @@ class ParallelPlugin(TrainingTypePlugin, ABC):
 
     @contextmanager
     def block_backward_sync(self):
-        """
-        Blocks ddp sync gradients behaviour on backwards pass.
+        """Blocks ddp sync gradients behaviour on backwards pass.
+
         This is useful for skipping sync when accumulating gradients, reducing communication overhead
         Returns: context manager with sync behaviour off
         """
@@ -131,15 +130,3 @@ class ParallelPlugin(TrainingTypePlugin, ABC):
                 yield None
         else:
             yield None
-
-    def teardown(self) -> None:
-        # Un-reference the wrapper if any was used.
-        # todo (tchaton): Add support for all plugins.
-        if isinstance(self.model, DistributedDataParallel):
-            self.model = self.lightning_module
-
-        if self.on_gpu:
-            # GPU teardown
-            self.lightning_module.cpu()
-            # clean up memory
-            torch.cuda.empty_cache()
