@@ -5,11 +5,11 @@ rank_zero_deprecation(
     "HINT: Use ``import pytorch_lightning.profiler`` directly."
 )
 
-from pytorch_lightning.profiler.advanced import AdvancedProfiler  # noqa E402
-from pytorch_lightning.profiler.base import AbstractProfiler, BaseProfiler, PassThroughProfiler  # noqa E402
-from pytorch_lightning.profiler.pytorch import PyTorchProfiler  # noqa E402
-from pytorch_lightning.profiler.simple import SimpleProfiler  # noqa E402
-from pytorch_lightning.profiler.xla import XLAProfiler  # noqa E402
+from pytorch_lightning.profiler.advanced import AdvancedProfiler  # noqa: E402
+from pytorch_lightning.profiler.base import AbstractProfiler, BaseProfiler, PassThroughProfiler  # noqa: E402
+from pytorch_lightning.profiler.pytorch import PyTorchProfiler  # noqa: E402
+from pytorch_lightning.profiler.simple import SimpleProfiler  # noqa: E402
+from pytorch_lightning.profiler.xla import XLAProfiler  # noqa: E402
 
 __all__ = [
     "AbstractProfiler",
