@@ -20,7 +20,7 @@ _PROJECT_ROOT = os.path.dirname(os.path.dirname(__file__))
 
 
 def _load_requirements(path_dir: str, file_name: str = "requirements.txt", comment_char: str = "#") -> List[str]:
-    """Load requirements from a file
+    """Load requirements from a file.
 
     >>> _load_requirements(_PROJECT_ROOT)  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
     ['numpy...', 'torch...', ...]
@@ -41,7 +41,7 @@ def _load_requirements(path_dir: str, file_name: str = "requirements.txt", comme
 
 
 def _load_readme_description(path_dir: str, homepage: str, version: str) -> str:
-    """Load readme as decribtion
+    """Load readme as decribtion.
 
     >>> _load_readme_description(_PROJECT_ROOT, "", "")  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
     '<div align="center">...'
